@charset "UTF-8";
div.phpdebugbar pre code.hljs {
  padding: 1em;
  display: block;
  overflow-x: auto;
}

div.phpdebugbar code.hljs {
  padding: 3px 5px;
}

div.phpdebugbar .hljs {
  color: var(--debugbar-text);
}

div.phpdebugbar .hljs-doctag, div.phpdebugbar .hljs-keyword, div.phpdebugbar .hljs-meta div.phpdebugbar .hljs-keyword, div.phpdebugbar .hljs-template-tag, div.phpdebugbar .hljs-template-variable, div.phpdebugbar .hljs-type, div.phpdebugbar .hljs-variable.language_ {
  color: #d73a49;
}

div.phpdebugbar .hljs-title, div.phpdebugbar .hljs-title.class_, div.phpdebugbar .hljs-title.class_.inherited__, div.phpdebugbar .hljs-title.function_ {
  color: #6f42c1;
}

div.phpdebugbar .hljs-attr, div.phpdebugbar .hljs-attribute, div.phpdebugbar .hljs-literal, div.phpdebugbar .hljs-meta, div.phpdebugbar .hljs-number, div.phpdebugbar .hljs-operator, div.phpdebugbar .hljs-variable, div.phpdebugbar .hljs-selector-attr, div.phpdebugbar .hljs-selector-class, div.phpdebugbar .hljs-selector-id {
  color: #005cc5;
}

div.phpdebugbar .hljs-regexp, div.phpdebugbar .hljs-string, div.phpdebugbar .hljs-meta div.phpdebugbar .hljs-string {
  color: #032f62;
}

div.phpdebugbar .hljs-built_in, div.phpdebugbar .hljs-symbol {
  color: #e36209;
}

div.phpdebugbar .hljs-comment, div.phpdebugbar .hljs-code, div.phpdebugbar .hljs-formula {
  color: #6a737d;
}

div.phpdebugbar .hljs-name, div.phpdebugbar .hljs-quote, div.phpdebugbar .hljs-selector-tag, div.phpdebugbar .hljs-selector-pseudo {
  color: #22863a;
}

div.phpdebugbar .hljs-subst {
  color: #24292e;
}

div.phpdebugbar .hljs-section {
  color: #005cc5;
  font-weight: bold;
}

div.phpdebugbar .hljs-bullet {
  color: #735c0f;
}

div.phpdebugbar .hljs-emphasis {
  color: #24292e;
  font-style: italic;
}

div.phpdebugbar .hljs-strong {
  color: #24292e;
  font-weight: bold;
}

div.phpdebugbar .hljs-addition {
  color: #22863a;
  background-color: #f0fff4;
}

div.phpdebugbar .hljs-deletion {
  color: #b31d28;
  background-color: #ffeef0;
}

div.phpdebugbar[data-theme="dark"] .hljs-doctag, div.phpdebugbar[data-theme="dark"] .hljs-keyword, div.phpdebugbar[data-theme="dark"] .hljs-meta div.phpdebugbar[data-theme="dark"] .hljs-keyword, div.phpdebugbar[data-theme="dark"] .hljs-template-tag, div.phpdebugbar[data-theme="dark"] .hljs-template-variable, div.phpdebugbar[data-theme="dark"] .hljs-type, div.phpdebugbar[data-theme="dark"] .hljs-variable.language_ {
  color: #ff7b72;
}

div.phpdebugbar[data-theme="dark"] .hljs-title, div.phpdebugbar[data-theme="dark"] .hljs-title.class_, div.phpdebugbar[data-theme="dark"] .hljs-title.class_.inherited__, div.phpdebugbar[data-theme="dark"] .hljs-title.function_ {
  color: #d2a8ff;
}

div.phpdebugbar[data-theme="dark"] .hljs-attr, div.phpdebugbar[data-theme="dark"] .hljs-attribute, div.phpdebugbar[data-theme="dark"] .hljs-literal, div.phpdebugbar[data-theme="dark"] .hljs-meta, div.phpdebugbar[data-theme="dark"] .hljs-number, div.phpdebugbar[data-theme="dark"] .hljs-operator, div.phpdebugbar[data-theme="dark"] .hljs-variable, div.phpdebugbar[data-theme="dark"] .hljs-selector-attr, div.phpdebugbar[data-theme="dark"] .hljs-selector-class, div.phpdebugbar[data-theme="dark"] .hljs-selector-id {
  color: #79c0ff;
}

div.phpdebugbar[data-theme="dark"] .hljs-regexp, div.phpdebugbar[data-theme="dark"] .hljs-string, div.phpdebugbar[data-theme="dark"] .hljs-meta div.phpdebugbar[data-theme="dark"] .hljs-string {
  color: #a5d6ff;
}

div.phpdebugbar[data-theme="dark"] .hljs-built_in, div.phpdebugbar[data-theme="dark"] .hljs-symbol {
  color: #ffa657;
}

div.phpdebugbar[data-theme="dark"] .hljs-comment, div.phpdebugbar[data-theme="dark"] .hljs-code, div.phpdebugbar[data-theme="dark"] .hljs-formula {
  color: #8b949e;
}

div.phpdebugbar[data-theme="dark"] .hljs-name, div.phpdebugbar[data-theme="dark"] .hljs-quote, div.phpdebugbar[data-theme="dark"] .hljs-selector-tag, div.phpdebugbar[data-theme="dark"] .hljs-selector-pseudo {
  color: #7ee787;
}

div.phpdebugbar[data-theme="dark"] .hljs-subst {
  color: #c9d1d9;
}

div.phpdebugbar[data-theme="dark"] .hljs-section {
  color: #1f6feb;
  font-weight: bold;
}

div.phpdebugbar[data-theme="dark"] .hljs-bullet {
  color: #f2cc60;
}

div.phpdebugbar[data-theme="dark"] .hljs-emphasis {
  color: #c9d1d9;
  font-style: italic;
}

div.phpdebugbar[data-theme="dark"] .hljs-strong {
  color: #c9d1d9;
  font-weight: bold;
}

div.phpdebugbar[data-theme="dark"] .hljs-addition {
  color: #aff5b4;
  background-color: #033a16;
}

div.phpdebugbar[data-theme="dark"] .hljs-deletion {
  color: #ffdcd7;
  background-color: #67060c;
}
